django-recommends
======================================

.. image:: https://travis-ci.org/fcurella/django-recommends.png?branch=master
    :target: https://travis-ci.org/fcurella/django-recommends

A django app that builds item-based suggestions for users.

Documentation on `readthedocs <http://django-recommends.rtfd.org/>`_.
